#
# spec file for package packunused
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           packunused
Version:        0.1.2
Release:        8.1
Summary:        Tool for detecting redundant Cabal package dependencies
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{name}-%{version}/revision/1.cabal#/%{name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-haskell-src-exts-devel
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-split-devel

%description
This simple CLI tool allows to find out which of the packages listed as
'build-depends' in a Cabal package description file are redundant.

'packunused' works by taking advantage of GHC's '-ddump-minimal-imports'
feature which creates '.import' files for each compiled module containing a
/minimal/ set of explicit import declarations. These '.import' files together
with Cabal's generated package configuration meta-data is analyzed by
'packunused' to detect potentially redundant package dependencies.

In order to use 'packunused' you have to configure the package as usual.
See the example session below:

> cabal clean > rm *.imports > cabal configure -O0 --disable-library-profiling
> cabal build --ghc-option=-ddump-minimal-imports > packunused

Experimental support for 'stack':

> stack setup --upgrade-cabal # necessary only when stack's global Cabal
installation is out of date > stack clean > stack build --ghc-options
'-ddump-minimal-imports -O0' > packunused

The '-O0 --disable-library-profiling' options are just to speed up compilation.
In some cases you might want to pass additional options to the 'configure'
step, such as '--enable-benchmark' or '--enable-tests'.

When run, 'packunused' prints a report to standard output listing its findings
for each component built. The following is an example for the 'packunused'
package itself, with a redundant dependency added for demonstration on purpose:

> detected package components > ~~~~~~~~~~~~~~~~~~~~~~~~~~~ > > -
executable(s): packunused > > (component names suffixed with '*' are not
configured to be built) > > executable(packunused) > ~~~~~~~~~~~~~~~~~~~~~~ > >
The following package dependencies seem redundant: > > -
criterion-0.6.2.0-9dd4d764629a47662168743b2dfda9bc >.

%prep
%setup -q
cp -p %{SOURCE1} %{name}.cabal

%build
%ghc_bin_build

%install
%ghc_bin_install

%files
%doc LICENSE
%doc changelog.md
%{_bindir}/%{name}

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 0.1.2 revision 1.
